@@ -18,10 +18,13 @@ def removeOldFiles(dirname, day = 3):
 	try:
 		os.listdir(dirname)
 	except:
-		return
+		return 0
+	count = 0 
 	for filename in os.listdir(dirname):
 		if os.path.getmtime(dirname + '/' + filename) < time.time() - 60 * 60 * 24 * day:
 			os.system('rm ' + dirname + '/' + filename)
+			count += 1
+	return count
 
 def parseDomain(url):
 	if not url:
@@ -32,10 +35,10 @@ def parseDomain(url):
 	if r.count('/') == 2 and 'http' in r:
 		return r
 
-def commitRepo(delay_minute = 1):
+def commitRepo(delay_minute = 1, commit_message = 'auto_commit_db'):
 	commands = [
 		'git add .',
-		'git commit -m commit',
+		'git commit -m ' + commit_message,
 		'git fetch origin', 
 		'git rebase origin/master',
 		'git push -u -f',
@@ -47,10 +50,15 @@ def commitRepo(delay_minute = 1):
 		threading.Timer(60 * delay_minute, lambda: os.system(command)).start()
 
 def cnWordCount(x):
+	if not x:
+		return 0
 	return len([c for c in x if c.isalpha() and ord(c) > 255])
 
+def getLogStr(*args):
+	return ' '.join([str(x) for x in args])
+
 def log(*args):
-	text = ' '.join([str(x) for x in args])
+	text = getLogStr(*args)
 	with open('nohup.out', 'a') as f:
 		f.write('%d:%d %s\n' % (dt.datetime.now().hour, dt.datetime.now().minute, text))
 
@@ -142,13 +150,17 @@ def getSoup(url):
 	r = requests.get(url, headers=headers)
 	return BeautifulSoup(r.text, 'html.parser')
 
+def isInt(item):
+	try:
+		int(item)
+		return True
+	except:
+		return False
+
 def getChat(bot, text):
 	text = text.split('/')[-1]
-	if not text.startswith('@'):
-		try:
-			int(text)
-		except:
-			text = "@" + text
+	if not text.startswith('@') and not isInt(text):
+		text = "@" + text
 	return bot.getChat(text)
 
 def getDisplayChat(chat):
